==> service_client-0.0.4-20211014.015544-7-sources.jar: com/northpool/service/config/vector_service/layer/LayerLevelBean.java <==
package com.northpool.service.config.vector_service.layer;






public class LayerLevelBean {
	/**
	 * 过滤条件
	 */
	protected String filterSQL = "";
	/**
	 * 抽稀参数 覆盖LayerDataSet的simplify
	 */
	protected Double simplifyForLayerLevel = DEFAULT_SIMPLIFY_VALUE;

	protected Integer lineCutBase = 400;

    protected Integer minCutPixel = 20;

	protected Integer minCutPoint = 2;

	public Double getSimplifyForLayerLevel() {
		return simplifyForLayerLevel;
	}
	public void setSimplifyForLayerLevel(Double simplifyForLayerLevel) {
		this.simplifyForLayerLevel = simplifyForLayerLevel;
	}

	protected SimplifyBean[] simplifyArr;
	/**
	 * 等级
	 */
	protected Integer level;
	/**
	 * 层级使用的数据集
	 */
	protected String dataSetId;
	
	/**
	 * 是否是虚层级
	 */
	protected Boolean virtual = false;
	
	
	public static final Double DEFAULT_SIMPLIFY_VALUE = 0d;

	public static final String NOT_CUT_FILTER = "1 = 2";
	
	/**
	 * 如果是点注记，则在简化点注记的时候最小网格中最多有多少个
	 */
	protected Integer pointSimplifyblockSize;
	/**
	 * 如果是点注记，则在简化点的时候的最小格网大小
	 */
	protected Integer pointSimplifyGridSize;
	public String getFilterSQL() {
		return filterSQL;
	}
	public void setFilterSQL(String filterSQL) {
		this.filterSQL = filterSQL;
	}
	public SimplifyBean[] getSimplifyArr() {
		return simplifyArr;
	}
	public void setSimplifyArr(SimplifyBean[] simplifyArr) {
		this.simplifyArr = simplifyArr;
	}
	public Integer getLevel() {
		return level;
	}
	public void setLevel(Integer level) {
		this.level = level;
	}
	public String getDataSetId() {
		return dataSetId;
	}
	public void setDataSetId(String dataSetId) {
		this.dataSetId = dataSetId;
	}
	public Boolean getVirtual() {
		return virtual;
	}

	public Integer getLineCutBase() {
		return lineCutBase;
	}

	public void setLineCutBase(Integer lineCutBase) {
		this.lineCutBase = lineCutBase;
	}

	public Integer getMinCutPixel() {
		return minCutPixel;
	}

	public void setMinCutPixel(Integer minCutPixel) {
		this.minCutPixel = minCutPixel;
	}

	public Integer getMinCutPoint() {
		return minCutPoint;
	}

	public void setMinCutPoint(Integer minCutPoint) {
		this.minCutPoint = minCutPoint;
	}

	public void addSQLFilter(String sql){
		if("".equals(this.filterSQL) || this.filterSQL == null){
			this.filterSQL = sql;
		}else{
			this.filterSQL = " and (" + sql + ")";
		}
	}
	

	
	
	/*public static LayerLevel createVirtual(Integer level,IDataSet dataSet){
		LayerLevel layerLevel = new LayerLevel();
		layerLevel.setLevel(level);
		layerLevel.setVirtual(true);
		layerLevel.setDataSet(dataSet);
		return layerLevel;
	}*/

	
	
	
}

==> service_client-0.0.4-20211221.064947-22-sources.jar: com/northpool/service/config/vector_service/layer/LayerLevelBean.java <==
package com.northpool.service.config.vector_service.layer;






public class LayerLevelBean {
	/**
	 * 过滤条件
	 */
	protected String filterSQL = "";
	/**
	 * 抽稀参数 覆盖LayerDataSet的simplify
	 */
	protected Double simplifyForLayerLevel = DEFAULT_SIMPLIFY_VALUE;

	protected Integer lineCutBase = 400;

    protected Integer minCutPixel = 20;

	protected Integer minCutPoint = 2;

	public Double getSimplifyForLayerLevel() {
		return simplifyForLayerLevel;
	}
	public void setSimplifyForLayerLevel(Double simplifyForLayerLevel) {
		this.simplifyForLayerLevel = simplifyForLayerLevel;
	}

	protected SimplifyBean[] simplifyArr;
	/**
	 * 等级
	 */
	protected Integer level;
	/**
	 * 层级使用的数据集
	 */
	protected String dataSetId;
	
	/**
	 * 是否是虚层级
	 */
	protected Boolean virtual = false;
	
	
	public static final Double DEFAULT_SIMPLIFY_VALUE = 0d;

	public static final String NOT_CUT_FILTER = "1 = 2";
	
	/**
	 * 如果是点注记，则在简化点注记的时候最小网格中最多有多少个
	 */
	protected Integer pointSimplifyblockSize;
	/**
	 * 如果是点注记，则在简化点的时候的最小格网大小
	 */
	protected Integer pointSimplifyGridSize;
	public String getFilterSQL() {
		return filterSQL;
	}
	public void setFilterSQL(String filterSQL) {
		this.filterSQL = filterSQL;
	}
	public SimplifyBean[] getSimplifyArr() {
		return simplifyArr;
	}
	public void setSimplifyArr(SimplifyBean[] simplifyArr) {
		this.simplifyArr = simplifyArr;
	}
	public Integer getLevel() {
		return level;
	}
	public void setLevel(Integer level) {
		this.level = level;
	}
	public String getDataSetId() {
		return dataSetId;
	}
	public void setDataSetId(String dataSetId) {
		this.dataSetId = dataSetId;
	}
	public Boolean getVirtual() {
		return virtual;
	}

	public Integer getLineCutBase() {
		return lineCutBase;
	}

	public void setLineCutBase(Integer lineCutBase) {
		this.lineCutBase = lineCutBase;
	}

	public Integer getMinCutPixel() {
		return minCutPixel;
	}

	public void setMinCutPixel(Integer minCutPixel) {
		this.minCutPixel = minCutPixel;
	}

	public Integer getMinCutPoint() {
		return minCutPoint;
	}

	public void setMinCutPoint(Integer minCutPoint) {
		this.minCutPoint = minCutPoint;
	}

	public void addSQLFilter(String sql){
		if("".equals(this.filterSQL) || this.filterSQL == null){
			this.filterSQL = sql;
		}else{
			this.filterSQL = this.filterSQL + " and (" + sql + ")";
		}
	}
	

	
	
	/*public static LayerLevel createVirtual(Integer level,IDataSet dataSet){
		LayerLevel layerLevel = new LayerLevel();
		layerLevel.setLevel(level);
		layerLevel.setVirtual(true);
		layerLevel.setDataSet(dataSet);
		return layerLevel;
	}*/

	
	
	
}
